==> maleo_security-0.0.1-py3-none-any.whl: maleo_security/clients/http/controllers/hash/sha256.py <==
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_security.clients.http.manager import MaleoSecurityHTTPClientManager
from maleo_security.models.transfers.parameters.hash.sha256 import MaleoSecuritySHA256HashParametersTransfers

class MaleoSecuritySHA256HashHTTPClientController:
    @staticmethod
    async def hash(parameters:MaleoSecuritySHA256HashParametersTransfers.Hash) -> BaseClientHTTPControllerResults:
        """Generate a sha256 hash for the given message."""
        async with MaleoSecurityHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.base_url}/v1/hashes/sha256/hash"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

    @staticmethod
    async def verify(parameters:MaleoSecuritySHA256HashParametersTransfers.Verify) -> BaseClientHTTPControllerResults:
        """Verify a message against the given message hash."""
        async with MaleoSecurityHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.base_url}/v1/hashes/sha256/verify"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

==> maleo_security-0.0.2-py3-none-any.whl: maleo_security/clients/http/controllers/hash/sha256.py <==
from maleo_foundation.models.transfers.results.client.controllers.http import BaseClientHTTPControllerResults
from maleo_security.clients.http.manager import MaleoSecurityHTTPClientManager
from maleo_security.models.transfers.parameters.hash.sha256 import MaleoSecuritySHA256HashParametersTransfers

class MaleoSecuritySHA256HashHTTPClientController:
    @staticmethod
    async def hash(parameters:MaleoSecuritySHA256HashParametersTransfers.Hash) -> BaseClientHTTPControllerResults:
        """Generate a sha256 hash for the given message."""
        async with MaleoSecurityHTTPClientManager.get_client() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.get_url()}/v1/hashes/sha256/hash"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)

    @staticmethod
    async def verify(parameters:MaleoSecuritySHA256HashParametersTransfers.Verify) -> BaseClientHTTPControllerResults:
        """Verify a message against the given message hash."""
        async with MaleoSecurityHTTPClientManager.get_client() as client:
            #* Define URL
            url = f"{MaleoSecurityHTTPClientManager.get_url()}/v1/hashes/sha256/verify"

            #* Define headers
            headers = {
                "Content-Type": "application/json"
            }

            #* Construct body
            json = parameters.model_dump()

            #* Get Response
            response = await client.post(url=url, json=json, headers=headers)
            return BaseClientHTTPControllerResults(response=response)
